from freenit.auth import permissions

domain_perms = permissions()
group_perms = permissions()
profile_perms = permissions()
role_perms = permissions()
theme_perms = permissions()
user_perms = permissions()
